@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
-our $DATE = '2017-01-04'; # DATE
-our $VERSION = '0.33'; # VERSION
+our $DATE = '2017-01-12'; # DATE
+our $VERSION = '0.34'; # VERSION
 
 use 5.010001;
 use strict;
@@ -29,13 +29,25 @@ our $re_archive_ext = qr/(?:tar|tar\.(?:Z|gz|bz2|xz)|zip|rar)/;
 our %common_args = (
     username => {
         summary => 'PAUSE ID',
-        schema  => ['str*', match=>'\A\w{2,9}\z', max_len=>9],
+        schema  => ['str*', match=>'\A\w{2,9}\z', max_len=>9], # see also: Regexp::Pattern::CPAN
+        description => <<'_',
+
+If unset, default value will be searched from `~/.pause`. Encrypted `.pause` is
+not yet supported.
+
+_
         req     => 1,
         tags    => ['common'],
     },
     password => {
         summary => 'PAUSE password',
         schema  => 'str*',
+        description => <<'_',
+
+If unset, default value will be searched from `~/.pause`. Encrypted `.pause` is
+not yet supported.
+
+_
         is_password => 1,
         req     => 1,
         tags    => ['common'],
@@ -51,7 +63,7 @@ our %common_args = (
     retry_delay => {
         summary => 'How long to wait before retrying',
         schema  => 'duration*',
-        default => "3s",
+        default => 3,
         tags    => ['common'],
     },
 );
@@ -142,6 +154,20 @@ sub _request {
 
     my %args = @_;
 
+    # set default for username and password from ~/.pause
+    my $username = $args{username};
+    my $password = $args{password};
+    {
+        last if defined $username && defined $password;
+        my $path = "$ENV{HOME}/.pause";
+        last unless -f $path;
+        open my($fh), "<", $path or last;
+        while (defined(my $line = <$fh>)) {
+            if ($line =~ /^user\s+(.+)/) { $username //= $1 }
+            elsif ($line =~ /^password\s+(.+)/) { $password //= $1 }
+        }
+    }
+
     state $ua = do {
         require LWP::UserAgent;
         LWP::UserAgent->new;
@@ -149,7 +175,7 @@ sub _request {
     my $req = HTTP::Request::Common::POST(
         "https://pause.perl.org/pause/authenquery",
         @{ $args{post_data} });
-    $req->authorization_basic($args{username}, $args{password});
+    $req->authorization_basic($username, $password);
 
     my $tries = 0;
     my $resp;
@@ -336,15 +362,6 @@ sub upload_files {
     $envres->as_struct;
 }
 
-# old name, deprecated
-{
-    no strict 'refs';
-    no warnings 'once';
-    *upload_file = \&upload_files;
-    $SPEC{upload_file} = { %{ $SPEC{upload_files} } }; # shallow clone
-    $SPEC{upload_file}{'x.no_index'} = 1;
-}
-
 $SPEC{list_files} = {
     v => 1.1,
     summary => 'List files',
@@ -892,13 +909,13 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.33 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-01-04.
+This document describes version 0.34 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-01-12.
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-This module provides several API functions for performing common tasks on PAUSE.
+This module provides several functions for performing common tasks on PAUSE.
 There is also a CLI script L<pause> distributed separately in L<App::pause>.
 
 =head1 FUNCTIONS
@@ -929,6 +946,9 @@ File names/wildcard patterns.
 
 PAUSE password.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =item * B<protect_files> => I<array[str]>
 
 Protect some files/wildcard patterns from delete/cleanup.
@@ -937,7 +957,7 @@ Protect some files/wildcard patterns from delete/cleanup.
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: "3s")
+=item * B<retry_delay> => I<duration> (default: 3)
 
 How long to wait before retrying.
 
@@ -945,6 +965,9 @@ How long to wait before retrying.
 
 PAUSE ID.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =back
 
 Special arguments:
@@ -1005,6 +1028,9 @@ second newest, and so on.
 
 PAUSE password.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =item * B<protect_files> => I<array[str]>
 
 Protect some files/wildcard patterns from delete/cleanup.
@@ -1013,7 +1039,7 @@ Protect some files/wildcard patterns from delete/cleanup.
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: "3s")
+=item * B<retry_delay> => I<duration> (default: 3)
 
 How long to wait before retrying.
 
@@ -1021,6 +1047,9 @@ How long to wait before retrying.
 
 PAUSE ID.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =back
 
 Special arguments:
@@ -1079,11 +1108,14 @@ Dev versions will be skipped.
 
 PAUSE password.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =item * B<retries> => I<int> (default: 2)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: "3s")
+=item * B<retry_delay> => I<duration> (default: 3)
 
 How long to wait before retrying.
 
@@ -1091,6 +1123,9 @@ How long to wait before retrying.
 
 PAUSE ID.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1131,11 +1166,14 @@ File names/wildcard patterns.
 
 PAUSE password.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =item * B<retries> => I<int> (default: 2)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: "3s")
+=item * B<retry_delay> => I<duration> (default: 3)
 
 How long to wait before retrying.
 
@@ -1143,6 +1181,9 @@ How long to wait before retrying.
 
 PAUSE ID.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1179,11 +1220,14 @@ Module names/wildcard patterns.
 
 PAUSE password.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =item * B<retries> => I<int> (default: 2)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: "3s")
+=item * B<retry_delay> => I<duration> (default: 3)
 
 How long to wait before retrying.
 
@@ -1195,6 +1239,9 @@ Only list modules matching certain type.
 
 PAUSE ID.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1230,11 +1277,14 @@ File names/wildcard patterns.
 
 PAUSE password.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =item * B<retries> => I<int> (default: 2)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: "3s")
+=item * B<retry_delay> => I<duration> (default: 3)
 
 How long to wait before retrying.
 
@@ -1242,6 +1292,9 @@ How long to wait before retrying.
 
 PAUSE ID.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =back
 
 Special arguments:
@@ -1291,11 +1344,14 @@ File names/wildcard patterns.
 
 PAUSE password.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =item * B<retries> => I<int> (default: 2)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: "3s")
+=item * B<retry_delay> => I<duration> (default: 3)
 
 How long to wait before retrying.
 
@@ -1303,6 +1359,9 @@ How long to wait before retrying.
 
 PAUSE ID.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =back
 
 Special arguments:
@@ -1377,11 +1436,14 @@ at once, you set this option to 2-3 minutes (120-180 seconds).
 
 PAUSE password.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =item * B<retries> => I<int> (default: 2)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: "3s")
+=item * B<retry_delay> => I<duration> (default: 3)
 
 How long to wait before retrying.
 
@@ -1393,6 +1455,9 @@ Subdirectory to put the file(s) into.
 
 PAUSE ID.
 
+If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
+not yet supported.
+
 =back
 
 Special arguments:
@@ -1439,7 +1504,7 @@ feature.
 L<CPAN::Uploader> which also does uploading from CLI.
 
 L<WWW::PAUSE::CleanUpHomeDir> which can clean old releases from your PAUSE
-account (CLI example is provided script).
+account (CLI script is provided in example).
 
 L<https://perlancar.wordpress.com/2015/03/25/interacting-with-pause-using-cli/>
 
